/********************************************************************************
 *   This file is part of JRtfTree.
 *
 *   JRtfTree is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   JRtfTree is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with JRtfTree; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 ********************************************************************************/	

/********************************************************************************
 * Library:		JRtfTree
 * Version:     v0.1.1b
 * Class:		RtfNodeCollection
 * Copyright:   2005 Salvador Gomez
 * Home Page:	http://www.sgoliver.net
 * SF Project:	http://nrtftree.sourceforge.net
 *				http://sourceforge.net/projects/nrtftree
 * Date:		15/01/2006
 * Description:	Representa un documento RTF en forma de rbol.
 * ******************************************************************************/

package net.sgoliver.jrtftree.core;

import java.util.ArrayList;

/**
 * Coleccin de nodos de un documento RTF. 
 */
public class RtfNodeCollection
{
	private ArrayList collection;
	
	/**
	 * Constructor de la coleccin. 
	 */
	public RtfNodeCollection()
	{
		collection = new ArrayList();
	}
	
	/**
	 * Aade un nuevo nodo a la coleccin actual.
	 * @param node Nuevo nodo a aadir.
	 * @return Posicin en la que se ha insertado el nuevo nodo.
	 */
    public int add(RtfTreeNode node)
    {
        collection.add(node);

        return (collection.size() - 1);
    }
    
    /**
     * Obtiene un elemento de la coleccin.
     * @param index Indice del nodo a obtener.
     * @return Devuelve el nodo que ocupa la posicin 'index' dentro de la coleccin.
     */
    public RtfTreeNode get(int index)
    {
    	return (RtfTreeNode)collection.get(index);
    }
    
    /**
     * Asigna un elemento de la coleccin.
     * @param index Indice del nodo a asignar.
     * @param node Nodo a asignar.
     */
    public void set(int index, RtfTreeNode node)
    {
    	collection.set(index,node);
    }
    
    /**
     * Devuelve el ndice del nodo pasado como parmetro dentro de la lista de nodos de la coleccin.
     * @param node Nodo a buscar en la coleccin.
     * @return Indice del nodo buscado. Devolver el valor -1 en caso de no encontrarse el nodo dentro de la coleccin.
     */
    public int indexOf(RtfTreeNode node)
    {
    	return collection.indexOf(node);
    }
    
    /**
     * Aade al final de la coleccin una nueva lista de nodos.
     * @param col Nueva lista de nodos a aadir a la coleccin actual.
     */
    public void addAll(RtfNodeCollection col)
    {
    	collection.addAll(col.collection);
    }
    
    /**
     * Elimina todos los nodos de la coleccin.
     */
    public void clear()
    {
    	collection.clear();
    }

    /**
     * Obtiene el tamao de la coleccin de nodos.
     * @return Devuelve el nmero de nodos de la coleccin.
     */
    public int size()
    {
    	return collection.size();
    }
    
    /**
     * Elimina un nodo de la coleccin a partir de su ndice.
     * @param index Indice del nodo a eliminar.
     */
    public void remove(int index)
    {
    	collection.remove(index);
    }
}
